@@ -17,7 +17,7 @@
 #
 """Choose the best html rendering
 
-$Id: ReportRenderHtml.py 53544 2009-03-09 16:28:58Z tlazar $
+$Id: ReportRenderHtml.py 54287 2011-02-04 23:40:50Z bdelbosc $
 """
 
 try:
@@ -27,6 +27,9 @@ except ImportError:
     try:
         # 2/ gdchart2
         from ReportRenderHtmlGDChart import RenderHtmlGDChart as RenderHtml
+        import warnings
+        warnings.warn('GDChart library is deprecated and will be removed '
+                      'in 1.15, FunkLoad is now using gnuplot > 4.2')
     except:
         # 3/ no charts
         from ReportRenderHtmlBase import RenderHtmlBase as RenderHtml
