@@ -27,6 +27,10 @@ import logging
 from time import sleep
 from socket import error as SocketError
 from xmlrpclib import ServerProxy
+import pkg_resources
+import tarfile
+import shutil
+import tempfile
 
 
 def thread_sleep(seconds=0):
@@ -162,7 +166,7 @@ def trace(message):
 def xmlrpc_get_credential(host, port, group=None):
     """Get credential thru xmlrpc credential_server."""
     url = "http://%s:%s" % (host, port)
-    server = ServerProxy(url)
+    server = ServerProxy(url, allow_none=True)
     try:
         return server.getCredential(group)
     except SocketError:
@@ -184,7 +188,7 @@ def xmlrpc_list_groups(host, port):
 def xmlrpc_list_credentials(host, port, group=None):
     """Get list of users thru xmlrpc credential_server."""
     url = "http://%s:%s" % (host, port)
-    server = ServerProxy(url)
+    server = ServerProxy(url, allow_none=True)
     try:
         return server.listCredentials(group)
     except SocketError:
@@ -288,3 +292,51 @@ class Data:
 
     def __repr__(self):
         return "[User data " + self.content_type + "]"
+
+
+def get_virtualenv_script():
+    """
+    returns the path of the virtualenv.py script that is 
+    installed in the system. if it doesn't exist returns
+    None.
+    """
+    pkg = pkg_resources.get_distribution('virtualenv')
+    script_path =  os.path.join( pkg.location, 'virtualenv.py')
+    
+    if os.path.isfile( script_path ):
+        return script_path
+    else:
+        return None
+
+
+def package_tests(module_file):
+    """
+    this function will basically allow you to create a tarball
+    of the current working directory (of tests) for transport over
+    to a remote machine. It uses a few heuristics to avoid packaging
+    log files.
+    """
+    exclude_func = lambda filename: filename.find(".log")>=0 or\
+                                    filename.find(".bak")>=0 or\
+                                    filename.find(".pyc")>=0 or\
+                                    os.path.split(filename)[1] == "bin" or\
+                                    os.path.split(filename)[1] == "lib" 
+        
+    _path = tempfile.mktemp(suffix='.tar') 
+    import hashlib
+    _targetdir = hashlib.md5(os.path.splitext(module_file)[0]).hexdigest()
+    _directory = os.path.split(os.path.abspath(module_file))[0]
+    _tar = tarfile.TarFile( _path  ,'w')
+    _tar.add ( _directory, _targetdir , exclude = exclude_func )
+    
+    return _path, _targetdir
+
+def extract_token(text, tag_start, tag_end):
+    """Extract a token from text, using the first occurence of
+    tag_start and ending with tag_end. Return None if tags are not
+    found."""
+    start = text.find(tag_start) + len(tag_start)
+    end = text.find(tag_end, start)
+    if start < 0 or end < 0:
+        return None
+    return text[start:end]
